smartcard.sw.SWExceptions.WarningProcessingException

# ``smartcard`.`sw`.`SWExceptions`.`WarningProcessingException``

exception documentation

`class WarningProcessingException(SWException):`

View In Hierarchy

Raised when a warning processing is detected from sw1, sw2. Examples of warning processing exception: sw1=62 or sw=63 (ISO7816-4).

Method | `__init__` | Undocumented

Inherited from `SWException`:

Method | `__str__` | Undocumented
Instance Variable | `data` | response apdu sw1
Instance Variable | `message` | response apdu data
Instance Variable | `sw1` | response apdu sw2
Instance Variable | `sw2` | Undocumented

def __init__(self, data, sw1, sw2, message=''):
overrides `smartcard.sw.SWExceptions.SWException.__init__`

Undocumented